@@ -91,24 +91,27 @@ class HookModelMixin(models.Model):
         is_create = self.pk is None
         ctx = HookContext(self.__class__)
 
-        # Use a single context manager for all hooks
+        # Let Django save first to handle form validation
+        super().save(*args, **kwargs)
+
+        # Then run our hooks with the validated data
         with patch_foreign_key_behavior():
             if is_create:
                 # For create operations
+                run(self.__class__, VALIDATE_CREATE, [self], ctx=ctx)
                 run(self.__class__, BEFORE_CREATE, [self], ctx=ctx)
-                super().save(*args, **kwargs)
                 run(self.__class__, AFTER_CREATE, [self], ctx=ctx)
             else:
                 # For update operations
                 try:
                     old_instance = self.__class__.objects.get(pk=self.pk)
+                    run(self.__class__, VALIDATE_UPDATE, [self], [old_instance], ctx=ctx)
                     run(self.__class__, BEFORE_UPDATE, [self], [old_instance], ctx=ctx)
-                    super().save(*args, **kwargs)
                     run(self.__class__, AFTER_UPDATE, [self], [old_instance], ctx=ctx)
                 except self.__class__.DoesNotExist:
                     # If the old instance doesn't exist, treat as create
+                    run(self.__class__, VALIDATE_CREATE, [self], ctx=ctx)
                     run(self.__class__, BEFORE_CREATE, [self], ctx=ctx)
-                    super().save(*args, **kwargs)
                     run(self.__class__, AFTER_CREATE, [self], ctx=ctx)
 
         return self
